is_toggle_word

Function is_toggle_word 

pub fn is_toggle_word(word: &str) -> bool
Whether a bare argument is a sub-action rather than a workspace path.

devp config hook <word> is ambiguous by design — <word> is either the action or the repository to apply it to — so both the argument router and parse_toggle have to agree on which words are actions.