Module hook

Module hook 

Enums

HookState
Where the global hook installation currently stands.

Constants

GIT_MISSING_HELP
Advice printed when git cannot be found.

Functions

chain_target
The hooks directory a chained install is forwarding to, if we are chaining.
git_available
Whether a usable git is on PATH.
hooks_dir
Return path to the dev-prune hooks directory (~/.config/dev-prune/hooks/).
install
Install non-blocking global Git hooks (post-commit, post-checkout, post-merge).
install_with
Install the hooks, optionally forwarding to the hooks directory already configured.
registered_exe_path
The binary the installed hooks will actually run, if there are hooks to read.
run_install
Install the hooks, printing the result and the caveats.
run_status
Show status of global Git hooks.
run_uninstall
Uninstall non-blocking global Git hooks.
shims_incomplete
Whether an unchained install is missing shims it should have.
state
Classify the current global hook installation.