sync_app_directory

Function sync_app_directory 

pub fn sync_app_directory() -> Result<()>
Write the icon assets and JSON Schema into the config directory, then register the file type with the OS file manager as far as the platform allows.