Module man

Module man 

Functions

run
Render the manual: a readable contents page on a terminal, one command’s page when a command is named, roff when redirected, and with --dir the full set of files — devp.1, dev-prune.1 (the same page under the binary’s other name) and one devp-<command>.1 per subcommand.