Module selection_view

Module selection_view 

Structs

SelectableCandidate
Candidate item for the selection list.

Functions

select_candidates_tui
Renders an interactive TUI list allowing the user to toggle which candidates to prune. Returns the list of candidates that the user selected for deletion.