select_candidates_tui

Function select_candidates_tui 

pub fn select_candidates_tui(
    candidates: &[PruneResult],
) -> Result<Vec<PruneResult>>
Renders an interactive TUI list allowing the user to toggle which candidates to prune. Returns the list of candidates that the user selected for deletion.