Functions
- run
- Render the manual: a readable contents page on a terminal, one command’s page when
a command is named, roff when redirected, and with
--dirthe full set of files —devp.1,dev-prune.1(the same page under the binary’s other name) and onedevp-<command>.1per subcommand.