Skip to main content Module config Copy item path Source LastPrune What the most recent prune pass deleted, for devp restore --last-run. PerRepoConfig Structured per-repository configuration file stored inside repo roots as .devprune.json. PruneRunSummary A one-line summary of a completed prune pass, for devp stats. PrunedDir One directory a prune pass deleted. Registry The top-level registry structure persisted to disk. RepoEntry Metadata for a single registered repository. Settings Global settings that control prune behavior. canonical_key Normalise a repository path into the form used as a registry key. ensure_in_gitignore Helper to ensure an entry (e.g. “.devprune.json”) is present in the repository’s .gitignore.
If .gitignore doesn’t exist, it creates it and adds the entry. expand_tilde Expand a leading ~ to the user’s home directory.