Module daemon

Module daemon 

Enums

DaemonStatus
Status of the background daemon task.

Functions

daemon_status
Check if the daemon is installed and its status.
get_exe_path
The binary path to register with the scheduler.
install_daemon
Install the OS-native daemon/scheduled task, firing every interval_days days.
registered_exe_path
The binary the installed scheduler entry will actually run, when that can be read.
uninstall_daemon
Uninstall the daemon/scheduled task.