Enums
- Daemon
Status - Status of the background daemon task.
Functions
- daemon_
status - Check if the daemon is installed and its status.
- get_
exe_ path - The binary path to register with the scheduler.
- install_
daemon - Install the OS-native daemon/scheduled task, firing every
interval_daysdays. - registered_
exe_ path - The binary the installed scheduler entry will actually run, when that can be read.
- uninstall_
daemon - Uninstall the daemon/scheduled task.