pub fn compute_display_name(repo_path: &Path, all_paths: &[PathBuf]) -> StringExpand description
Compute crisp, disambiguated project names for a repository path.
Uses .devprune.json custom project_name if present. Otherwise defaults to folder name.
If multiple repositories share the exact same folder name, disambiguates by including parent folder.