pub enum ConfigAction {
Get {
key: String,
},
Set {
key: String,
value: String,
},
Show {
update: bool,
},
Project {
path: String,
update: bool,
},
Daemon {
target: Option<String>,
sub_action: Option<String>,
},
Hook {
target: Option<String>,
sub_action: Option<String>,
chain: bool,
},
Icon,
Wizard {
no_tui: bool,
},
}Variants
Get
Display a global configuration value.
Fields
Set
Set a global configuration value.
Show
Show all global configuration values or sync per-repo configurations.
Project
Inspect or initialize per-repository config (.devprune.json) for a workspace path.
Fields
Daemon
Configure OS background daemon scheduler globally or for a workspace path.
Fields
Hook
Configure non-blocking global Git background auto-registration hooks globally or for a workspace path.
Fields
Icon
Register a file-manager icon for .devprune.json, and print an editor snippet.
Wizard
Walk through every global setting, confirming or changing each one.