Module git

Module git 

Functions

get_last_activity
Get the last activity time for a repository.
get_last_commit_time
Get the timestamp of the most recent commit in a repository.
get_mtime_activity
Scan all source files in a repo and return the latest mtime.
is_idle_at
Whether an already-known activity time counts as idle.
is_repo_idle
Check if a repository is considered “idle” (inactive for idle_days).