Functions
- get_
last_ activity - Get the last activity time for a repository.
- get_
last_ commit_ time - Get the timestamp of the most recent commit in a repository.
- get_
mtime_ activity - Scan all source files in a repo and return the latest
mtime. - is_
idle_ at - Whether an already-known activity time counts as idle.
- is_
repo_ idle - Check if a repository is considered “idle” (inactive for
idle_days).