Structs
- Selectable
Candidate - Candidate item for the selection list.
Functions
- select_
candidates_ tui - Renders an interactive TUI list allowing the user to toggle which candidates to prune. Returns the list of candidates that the user selected for deletion.